Package: nlme
Version: 3.1-77
Date: 2006-09-28
Priority: recommended
Title: Linear and nonlinear mixed effects models
Author: Jose Pinheiro <Jose.Pinheiro@pharma.novartis.com>,
        Douglas Bates <bates@stat.wisc.edu>,
        Saikat DebRoy <saikat@stat.wisc.edu>, and
        Deepayan Sarkar <deepayan@stat.wisc.edu>
Maintainer: R-core <R-core@R-project.org>
Description: Fit and compare Gaussian linear and nonlinear mixed-effects models.
Depends: graphics, stats, R (>= 2.3.0)
Imports: lattice
LazyLoad: yes
LazyData: yes
License: GPL version 2 or later
Packaged: Thu Sep 28 09:53:57 2006; bates
